# Spycial

Spycial is a collection of special functions written in pure Python
and accelerated by Numba. The goals are to

- make functionality comparable to SciPy's special module accessible
  inside Numba jitted functions
- have simpler internals by keeping all implementations written in
  Python
